@@ -2,6 +2,7 @@
 #include <regex>
 #include <Rcpp.h>
 #include "date.h"
+#include <RcppCCTZ_API.h>
 #include "nanotime/period.hpp"
 #include "nanotime/duration.hpp"
 #include "nanotime/pseudovector.hpp"
@@ -32,14 +33,9 @@ std::ostream &operator<<(std::ostream &stream,
 }
 
 
-extern "C" int getOffset(long long s, const char* tzstr);
-
 static inline duration getOffsetCnv(const dtime& dt, const std::string& z) {
-  typedef int GET_OFFSET_FUN(long long, const char*, int&); 
-  GET_OFFSET_FUN *getOffset = (GET_OFFSET_FUN *) R_GetCCallable("RcppCCTZ", "_RcppCCTZ_getOffset_nothrow" );
-
   int offset;
-  int res = getOffset(std::chrono::duration_cast<std::chrono::seconds>(dt.time_since_epoch()).count(), z.c_str(), offset);
+  int res = RcppCCTZ::getOffset(std::chrono::duration_cast<std::chrono::seconds>(dt.time_since_epoch()).count(), z.c_str(), offset);
   if (res < 0) {
     Rcpp::stop("Cannot retrieve timezone '%s'.", z.c_str()); // ## nocov
   }
@@ -162,9 +158,15 @@ dtime nanotime::plus(const dtime& dt, const period& p, const std::string& z) {
   offset = getOffsetCnv(dt, z);
   res += p.getDays()*std::chrono::hours(24);
   res += p.getDuration();
-  auto newoffset = getOffsetCnv(res, z);
-  if (newoffset != offset) {
-    res += offset - newoffset; // adjust for DST or any other event that changed the TZ
+  auto new_offset = getOffsetCnv(res, z);
+  // adjust for DST or any other event that changed the TZ, but only
+  // if the adjustment does not put us back in the old offset:
+  if (new_offset != offset) {
+    auto res_potential = res + offset - new_offset; // adjust
+    auto adjusted_offset = getOffsetCnv(res_potential, z);
+    if (adjusted_offset == new_offset) { // are we still in the new offset?
+      res = res_potential;               // if so, then keep the adjustment
+    }
   }
   return res;
 }
